aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorGravatar Sadie Powell2023-06-29 22:29:34 +0100
committerGravatar Sadie Powell2023-06-29 22:52:07 +0100
commit1d96baaf774eacd5eacd357500a01af693aad654 (patch)
tree8c2e960bba6dc28f9c381c27a9c38524fda56946 /include
parentFix remote users on legacy servers not having a real username. (diff)
Remove OnPreChange{Host,RealName} events and deboolify methods.
These have not ever been used as far as I can see.
Diffstat (limited to 'include')
-rw-r--r--include/modules.h18
-rw-r--r--include/users.h13
2 files changed, 5 insertions, 26 deletions
diff --git a/include/modules.h b/include/modules.h
index 16b0c1e27..70d37a1df 100644
--- a/include/modules.h
+++ b/include/modules.h
@@ -177,8 +177,6 @@ enum Implementation
I_OnPostOperLogout,
I_OnPostTopicChange,
I_OnPreChangeConnectClass,
- I_OnPreChangeHost,
- I_OnPreChangeRealName,
I_OnPreCommand,
I_OnPreMode,
I_OnPreOperLogin,
@@ -839,22 +837,6 @@ public:
*/
virtual ModResult OnCheckPassword(const std::string& password, const std::string& passwordhash, const std::string& value);
- /** Called whenever a change of a local users displayed host is attempted.
- * Return 1 to deny the host change, or 0 to allow it.
- * @param user The user whose host will be changed
- * @param newhost The new hostname
- * @return 1 to deny the host change, 0 to allow
- */
- virtual ModResult OnPreChangeHost(LocalUser* user, const std::string& newhost);
-
- /** Called whenever a change of a local users real name is attempted.
- * return MOD_RES_DENY to deny the name change, or MOD_RES_ALLOW to allow it.
- * @param user The user whose real name will be changed
- * @param newhost The new real name.
- * @return MOD_RES_DENY to deny the real name change, MOD_RES_ALLOW to allow
- */
- virtual ModResult OnPreChangeRealName(LocalUser* user, const std::string& newhost);
-
/** Called before a topic is changed.
* Return 1 to deny the topic change, 0 to check details on the change, -1 to let it through with no checks
* As with other 'pre' events, you should only ever block a local event.
diff --git a/include/users.h b/include/users.h
index 28a689297..dd74bb6c7 100644
--- a/include/users.h
+++ b/include/users.h
@@ -703,9 +703,8 @@ public:
/** Change the displayed hostname of this user.
* @param host The new displayed hostname of this user.
- * @return True if the hostname was changed successfully; otherwise, false.
*/
- bool ChangeDisplayedHost(const std::string& host);
+ void ChangeDisplayedHost(const std::string& host);
/** Change the real hostname of this user.
* @param host The new real hostname of this user.
@@ -715,9 +714,8 @@ public:
/** Change the displayed username of this user.
* @param newuser The new displayed username of this user.
- * @return True if the username was changed successfully; otherwise, false.
*/
- bool ChangeDisplayedUser(const std::string& newuser);
+ void ChangeDisplayedUser(const std::string& newuser);
/** Change the real username of this user.
* @param newuser The new real username of this user.
@@ -725,11 +723,10 @@ public:
*/
void ChangeRealUser(const std::string& newuser, bool resetdisplay);
/** Change a users realname field.
* @param real The user's new real name
* @return True if the change succeeded, false if otherwise
*/
- bool ChangeRealName(const std::string& real);
+ void ChangeRealName(const std::string& newreal);
/** Change a user's nick
* @param newnick The new nick. If equal to the users uuid, the nick change always succeeds.
@@ -725,11 +723,10 @@ public:
*/
void ChangeRealUser(const std::string& newuser, bool resetdisplay);
- /** Change a users realname field.
- * @param real The user's new real name
- * @return True if the change succeeded, false if otherwise
+ /** Change the real name of this user.
+ * @param newreal The new real name of this user.
*/